@@ -10,7 +10,7 @@ import string
 import base64
 
 from dateutil import rrule, tz
-import six
+import io
 
 try:
     import pytz
@@ -29,7 +29,7 @@ except ImportError:
     pytz = Pytz  # keeps quantifiedcode happy
 
 from . import behavior
-from .base import (VObjectError, NativeError, ValidateError, ParseError,
+from .base import (VERSION, VObjectError, NativeError, ValidateError, ParseError,
                    Component, ContentLine, logger, registerBehavior,
                    backslashEscape, foldOneLine)
 
@@ -38,13 +38,13 @@ from .base import (VObjectError, NativeError, ValidateError, ParseError,
 DATENAMES = ("rdate", "exdate")
 RULENAMES = ("exrule", "rrule")
 DATESANDRULES = ("exrule", "rrule", "rdate", "exdate")
-PRODID = u"-//PYVOBJECT//NONSGML Version 1//EN"
+PRODID = u"-//PYVOBJECT//NONSGML Version %s//EN" % VERSION
 
 WEEKDAYS = "MO", "TU", "WE", "TH", "FR", "SA", "SU"
 FREQUENCIES = ('YEARLY', 'MONTHLY', 'WEEKLY', 'DAILY', 'HOURLY', 'MINUTELY',
                'SECONDLY')
 
-zeroDelta = datetime.timedelta(0)
+ZERO_DELTA = datetime.timedelta(0)
 twoHours = datetime.timedelta(hours=2)
 
 
@@ -56,7 +56,7 @@ def toUnicode(s):
     """
     Take a string or unicode, turn it into unicode, decoding as utf-8
     """
-    if isinstance(s, six.binary_type):
+    if isinstance(s, bytes):
         s = s.decode('utf-8')
     return s
 
@@ -135,7 +135,7 @@ class TimezoneComponent(Component):
         good_lines = ('rdate', 'rrule', 'dtstart', 'tzname', 'tzoffsetfrom',
                       'tzoffsetto', 'tzid')
         # serialize encodes as utf-8, cStringIO will leave utf-8 alone
-        buffer = six.StringIO()
+        buffer = io.StringIO()
         # allow empty VTIMEZONEs
         if len(self.contents) == 0:
             return None
@@ -330,28 +330,30 @@ class TimezoneComponent(Component):
         """
         Given a tzinfo class, use known APIs to determine TZID, or use tzname.
         """
+
+        # If tzinfo is UTC, we don't need a TZID
         if tzinfo is None or (not allowUTC and tzinfo_eq(tzinfo, utc)):
-            # If tzinfo is UTC, we don't need a TZID
             return None
-        # try Pytz's tzid key
+
+        # Try pytz tzid key
         if hasattr(tzinfo, 'tzid'):
             return toUnicode(tzinfo.tzid)
 
-        # try pytz zone key
+        # Try pytz zone key
         if hasattr(tzinfo, 'zone'):
             return toUnicode(tzinfo.zone)
 
-        # try tzical's tzid key
-        elif hasattr(tzinfo, '_tzid'):
+        # Try tzical's tzid key
+        if hasattr(tzinfo, '_tzid'):
             return toUnicode(tzinfo._tzid)
-        else:
-            # return tzname for standard (non-DST) time
-            notDST = datetime.timedelta(0)
-            for month in range(1, 13):
-                dt = datetime.datetime(2000, month, 1)
-                if tzinfo.dst(dt) == notDST:
-                    return toUnicode(tzinfo.tzname(dt))
-        # there was no standard time in 2000!
+
+        # Return tzname for standard (non-DST) time
+        for month in range(1, 13):
+            dt = datetime.datetime(2000, month, 1)
+            if tzinfo.dst(dt) == ZERO_DELTA:
+                return toUnicode(tzinfo.tzname(dt))
+
+        # There was no standard time in 2000!
         raise VObjectError("Unable to guess TZID for tzinfo {0!s}"
                            .format(tzinfo))
 
@@ -567,7 +569,7 @@ class RecurringComponent(Component):
                     self.add(name).value = setlist
             elif name in RULENAMES:
                 for rule in setlist:
-                    buf = six.StringIO()
+                    buf = io.StringIO()
                     buf.write('FREQ=')
                     buf.write(FREQUENCIES[rule._freq])
 
@@ -1008,7 +1010,7 @@ class VCalendar2_0(VCalendarComponentBehavior):
             transformed = obj
             undoTransform = False
         out = None
-        outbuf = buf or six.StringIO()
+        outbuf = buf or io.StringIO()
         if obj.group is None:
             groupString = ''
         else:
@@ -1744,8 +1746,8 @@ def stringToDateTime(s, tzinfo=None, strict=False):
             tzinfo = getTzid('UTC')
     except:
         raise ParseError("'{0!s}' is not a valid DATE-TIME".format(s))
-    year = year and year or 2000
-    if tzinfo is not None and hasattr(tzinfo,'localize'):  # PyTZ case
+    year = year if year else 2000
+    if tzinfo is not None and hasattr(tzinfo,'localize'):  # Cater for pytz tzinfo instanes
         return tzinfo.localize(datetime.datetime(year, month, day, hour, minute, second))
     return datetime.datetime(year, month, day, hour, minute, second, 0, tzinfo)
 
@@ -2018,7 +2020,7 @@ def getTransition(transitionTo, year, tzinfo):
     if transitionTo == 'daylight':
         def test(dt):
             try:
-                return tzinfo.dst(dt) != zeroDelta
+                return tzinfo.dst(dt) != ZERO_DELTA
             except pytz.NonExistentTimeError:
                 return True  # entering daylight time
             except pytz.AmbiguousTimeError:
@@ -2026,7 +2028,7 @@ def getTransition(transitionTo, year, tzinfo):
     elif transitionTo == 'standard':
         def test(dt):
             try:
-                return tzinfo.dst(dt) == zeroDelta
+                return tzinfo.dst(dt) == ZERO_DELTA
             except pytz.NonExistentTimeError:
                 return False  # entering daylight time
             except pytz.AmbiguousTimeError:
